import { createRouter, createWebHistory } from 'vue-router'
import NProgress from 'nprogress'
import 'nprogress/nprogress.css'

const routes = [
  {
    path: '/login',
    name: 'Login',
    component: () => import('@/views/login.vue')
  },
  {
    path: '/',
    component: () => import('@/layout/layout.vue'),
    redirect: '/dashboard',
    children: [
      {
        path: 'dashboard',
        name: 'Dashboard',
        component: () => import('@/views/dashboard.vue'),
        meta: { title: 'menu.dashboard', icon: 'Odometer' }
      },
      {
        path: 'domain',
        name: 'Domain',
        component: () => import('@/views/domain.vue'),
        meta: { title: 'menu.domain', icon: 'Connection' }
      },
      {
        path: 'addDomain',
        name: 'AddDomain',
        component: () => import('@/views/addDomain.vue'),
        meta: { title: 'menu.addDomain', icon: 'Connection' }
      },
      {
        path: 'statistics',
        name: 'Statistics',
        component: () => import('@/views/statistics.vue'),
        meta: { title: 'menu.statistics', icon: 'DataAnalysis' }
      },
      {
        path: 'refresh',
        name: 'Refresh',
        component: () => import('@/views/refresh.vue'),
        meta: { title: 'menu.refresh', icon: 'Refresh' }
      },
      {
        path: 'certificate',
        name: 'Certificate',
        component: () => import('@/views/certificate.vue'),
        meta: { title: 'menu.certificate', icon: 'Lock' }
      },
      {
        path: 'addCertificate',
        name: 'addCertificate',
        component: () => import('@/views/addCertificate.vue'),
        meta: { title: 'menu.certificate', icon: 'Lock' }
      },
      {
        path: 'account',
        name: 'Account',
        component: () => import('@/views/account.vue'),
        meta: { title: 'menu.account', icon: 'Setting' }
      }
    ]
  }
]

const router = createRouter({
  history: createWebHistory(),
  routes,
  scrollBehavior: () => ({ top: 0 })
})

// 配置NProgress
NProgress.configure({ showSpinner: false })

// 全局前置守卫
router.beforeEach((to, from, next) => {
  // 开启进度条
  NProgress.start()
  
  const token = localStorage.getItem('token')
  if (to.path === '/login') {
    if (token) {
      next('/')
    } else {
      next()
    }
  } else {
    if (token) {
      next()
    } else {
      next('/login')
    }
  }
})

// 全局后置守卫
router.afterEach(() => {
  // 关闭进度条
  NProgress.done()
})

export default router 